<?php

namespace Drupal\vipps_mobilepay_commerce_express\Plugin\Commerce\PaymentGateway;

use Drupal\Core\Form\FormStateInterface;
use Drupal\vipps_mobilepay_commerce\Plugin\Commerce\PaymentGateway\Checkout;

/**
 * Provides the Vipps MobilePay Express payment gateway.
 *
 * @CommercePaymentGateway(
 *   id = "vipps_mobilepay_checkout_express",
 *   label = "Vipps MobilePay Checkout Express",
 *   display_label = "Vipps MobilePay Checkout Express",
 *    forms = {
 *     "offsite-payment" = "Drupal\vipps_mobilepay_commerce\PluginForm\OffsiteRedirect\CheckoutLandingPageRedirectForm",
 *   },
 *   requires_billing_information = FALSE,
 *   js_library="vipps_mobilepay_commerce/checkout_iframe",
 * )
 */
class CheckoutExpress extends Checkout {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $configuration = parent::defaultConfiguration();
    $configuration['enforce_vipps_mobilepay_checkout'] = FALSE;
    return $configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['enforce_vipps_mobilepay_checkout'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enforce checkout via Vipps Mobilepay'),
      '#description' => $this->t('Enabling this option ensure the user data is always collected using Vipps Mobilepay and not built-in Commerce Checkout'),
      '#default_value' => $this->configuration['enforce_vipps_mobilepay_checkout'] ?? FALSE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['enforce_vipps_mobilepay_checkout'] = $values['enforce_vipps_mobilepay_checkout'];
    }
  }

}
